pub struct ContractSister { /* private fields */ }Expand description
Contract facade wrapping the ContractEngine with SDK trait implementations.
Contract is session-scoped: policies and governance rules are loaded into a session context and can be queried, grounded, and audited.